tifft
=====

Technical Indicators for Financial Trading

Installation
------------

```sh
$ pip install -U https://github.com/dceoy/tifft/archive/main.tar.gz
```

Docker image
------------

The image is available at [Docker Hub](https://hub.docker.com/r/dceoy/tifft/).

```sh
$ docker pull dceoy/tifft
```

Usage
-----

Run `tifft --help` for information.
